﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.Extensions.Caching.Distributed;

using System.IO;
using System.Text;

namespace dotnet_hello_world.Pages;

public class IndexModel : PageModel
{
    private readonly ILogger<IndexModel> _logger;
    private readonly IServiceProvider _serviceProvider;
    private readonly IConfigurationRoot _configurationRoot;

    private readonly IWebHostEnvironment _webHostEnvironment;

    [BindProperty]
    public string Name { get; set; } = string.Empty;

    [ViewData]
    public string[] SavedNames
    {
        get
        {
            if (!System.IO.File.Exists("/var/lib/hello/names.txt"))
            {
                System.IO.File.Create("/var/lib/hello/names.txt").Dispose();
            }
            return System.IO.File.ReadAllLines("/var/lib/hello/names.txt");
        }
    }

    public IndexModel(ILogger<IndexModel> logger, IConfiguration configRoot, IWebHostEnvironment hostEnvironment, IServiceProvider serviceProvider)
    {
        _logger = logger;
        _serviceProvider = serviceProvider;
        _configurationRoot = (IConfigurationRoot)configRoot;
        _webHostEnvironment = hostEnvironment;
    }

    public async Task OnGetAsync()
    {
        ViewData["savedNames"] = SavedNames;
        ViewData["startupTime"] = "No cached time found";

        IDistributedCache? cache = null;
        string cachedTime = string.Empty;
        try {
            cache = _serviceProvider.GetService<IDistributedCache>();
        } catch (Exception) { }

        if (cache != null) {
            var encodedCachedTimeUTC = await cache.GetAsync("startupTimeUTC");
            if (encodedCachedTimeUTC != null)
            {
                cachedTime = Encoding.UTF8.GetString(encodedCachedTimeUTC);
            }
        }

        if (!string.IsNullOrEmpty(cachedTime)) {
            ViewData["startupTime"] = cachedTime;
        }
    }

    public void OnPost()
    {
        ViewData["successText"] = $"Successfully saved {Name}";
        _logger.LogInformation($"Found {Name}");
        System.IO.File.AppendAllText("/var/lib/hello/names.txt", $"{Name}\n");
    }
}
